@@ -31,7 +31,7 @@ import (
 )
 
 const (
-	version             = "0.6.1"
+	version             = "0.6.2"
 	nsBOSH              = "urn:xmpp:alt-connections:xbosh"
 	nsC2SdTLS           = "urn:xmpp:alt-connections:tls"
 	nsC2SQuic           = "urn:xmpp:alt-connections:quic"
@@ -215,33 +215,41 @@ func main() {
 		if len(*flagClientDTLS) > 0 {
 			for _, cdtls := range *flagClientDTLS {
 				target := strings.SplitN(cdtls, ":", 2)
-				port, err := strconv.ParseUint(target[1], 10, 16)
-				if err != nil {
-					fmt.Println(err)
-					continue
+				if len(target) == 2 {
+					port, err := strconv.ParseUint(target[1], 10, 16)
+					if err != nil {
+						log.Fatalf("client-dtls: failed to parse target (domain:port): %s: %v",
+							cdtls, err)
+					}
+					cr := xmppsrv.SRV{
+						Type:   "xmpps-client",
+						Target: target[0],
+						Port:   uint16(port),
+					}
+					clientRecords = append(clientRecords, cr)
+				} else {
+					log.Fatalf("client-dtls: failed to parse target (domain:port): %s\n", cdtls)
 				}
-				cr := xmppsrv.SRV{
-					Type:   "xmpps-client",
-					Target: target[0],
-					Port:   uint16(port),
-				}
-				clientRecords = append(clientRecords, cr)
 			}
 		}
 		if len(*flagClientSTLS) > 0 {
 			for _, cstls := range *flagClientSTLS {
 				target := strings.SplitN(cstls, ":", 2)
-				port, err := strconv.ParseUint(target[1], 10, 16)
-				if err != nil {
-					fmt.Println(err)
-					continue
+				if len(target) == 2 {
+					port, err := strconv.ParseUint(target[1], 10, 16)
+					if err != nil {
+						log.Fatalf("client-stls: failed to parse target (domain:port): %s: %v",
+							cstls, err)
+					}
+					cr := xmppsrv.SRV{
+						Type:   "xmpp-client",
+						Target: target[0],
+						Port:   uint16(port),
+					}
+					clientRecords = append(clientRecords, cr)
+				} else {
+					fmt.Printf("client-stls: failed to parse target (domain:port): %s\n", cstls)
 				}
-				cr := xmppsrv.SRV{
-					Type:   "xmpp-client",
-					Target: target[0],
-					Port:   uint16(port),
-				}
-				clientRecords = append(clientRecords, cr)
 			}
 		}
 		if *flagForceFallback && !fallback && *flagTest {
@@ -289,33 +297,41 @@ func main() {
 		if len(*flagServerDTLS) > 0 {
 			for _, sdtls := range *flagServerDTLS {
 				target := strings.SplitN(sdtls, ":", 2)
-				port, err := strconv.ParseUint(target[1], 10, 16)
-				if err != nil {
-					fmt.Println(err)
-					continue
+				if len(target) == 2 {
+					port, err := strconv.ParseUint(target[1], 10, 16)
+					if err != nil {
+						log.Fatalf("server-dtls: failed to parse target (domain:port): %s: %v",
+							sdtls, err)
+					}
+					sr := xmppsrv.SRV{
+						Type:   "xmpps-server",
+						Target: target[0],
+						Port:   uint16(port),
+					}
+					serverRecords = append(serverRecords, sr)
+				} else {
+					fmt.Printf("server-dtls: failed to parse target (domain:port): %s\n", sdtls)
 				}
-				sr := xmppsrv.SRV{
-					Type:   "xmpps-server",
-					Target: target[0],
-					Port:   uint16(port),
-				}
-				serverRecords = append(serverRecords, sr)
 			}
 		}
 		if len(*flagServerSTLS) > 0 {
 			for _, sstls := range *flagServerSTLS {
 				target := strings.SplitN(sstls, ":", 2)
-				port, err := strconv.ParseUint(target[1], 10, 16)
-				if err != nil {
-					fmt.Println(err)
-					continue
+				if len(target) == 2 {
+					port, err := strconv.ParseUint(target[1], 10, 16)
+					if err != nil {
+						log.Fatalf("server-stls: failed to parse target (domain:port): %s: %v",
+							sstls, err)
+					}
+					sr := xmppsrv.SRV{
+						Type:   "xmpp-server",
+						Target: target[0],
+						Port:   uint16(port),
+					}
+					serverRecords = append(serverRecords, sr)
+				} else {
+					fmt.Printf("server-stls: failed to parse target (domain:port): %s\n", sstls)
 				}
-				sr := xmppsrv.SRV{
-					Type:   "xmpp-server",
-					Target: target[0],
-					Port:   uint16(port),
-				}
-				serverRecords = append(serverRecords, sr)
 			}
 		}
 		if *flagForceFallback && !fallback && *flagTest {
@@ -1195,10 +1211,15 @@ func checkCertExpiry(c *tls.Conn) {
 	now := time.Now()
 	switch {
 	case time.Until(expiry).Hours() < 336:
-		fmt.Printf("[%sWARN%s]", colorYellow, colorReset)
+		fmt.Printf("Test: [%sWARN%s]", colorYellow, colorReset)
 		printTLSVersion(c.ConnectionState().Version)
-		fmt.Printf(" (Cert expires in %d days at %s)\n",
-			int(time.Until(expiry).Hours())/24, expiry.Truncate(time.Second).String())
+		expiryDays := int(time.Until(expiry).Hours())/24 + 1
+		dayString := fmt.Sprintf("%d days", expiryDays)
+		if expiryDays == 1 {
+			dayString = "one day"
+		}
+		fmt.Printf(" (Cert expires in less than %s at %s)\n",
+			dayString, expiry.Truncate(time.Second).String())
 	case now.Before(expiry) && now.After(start):
 		fmt.Print(statusOK)
 		printTLSVersion(c.ConnectionState().Version)
